# FancyKimai

This is a CLI created to interact with Kimai2 without needing to open the browser.

## Installation

```bash
pip install fancykimai
```

## Usage

```bash
kimai --help
```

## License

[GNU GPLv3](LICENSE)
